@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 926 2008-10-06 02:39:19Z pronovic $
+# Revision : $Id: release.py 933 2008-12-09 02:07:06Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2008"
-VERSION     = "2.19.0"
-DATE        = "05 Oct 2008"
+VERSION     = "2.19.2"
+DATE        = "08 Dec 2008"
 URL         = "http://cedar-backup.sourceforge.net/"
 
